@@ -34,7 +34,7 @@ class MySQLClient(ClientBase):
         sql = 'show fields from ' + tablename
         res = self.query(sql, show_sql=False)
         if isinstance(res,Iterable):
-            self._tables[tablename] = list(map(lambda x: x[0],res))
+            self._tables[tablename] = dict(zip(list(map(lambda x: x[0],res)),res))
         return res
 
     def _load_tables(self, show_sql=False):
@@ -141,3 +141,6 @@ class MySQLClient(ClientBase):
         #  #
         r = self.query(sql, show_sql, sql_params)
         return r
+
+    def show_database(self):
+        return self._tables
\ No newline at end of file
