@@ -5,7 +5,7 @@ import time
 
 from anduin.common import ENGINE_SQLITE,get_db_index,dbg
 from anduin.db.sql.sqlite.db_client import SQLiteClient
-from anduin.frames.manager_base import ManagerBase
+from anduin.frames.manager_base import ManagerBase, TIMEOUT
 
 
 class SQLiteManager(ManagerBase):
@@ -13,11 +13,11 @@ class SQLiteManager(ManagerBase):
         super().__init__(config)
 
     def create_connection(self):
+        dbg('无可用空闲链接，创建链接...', get_db_index(self.t_data))
         db_client = SQLiteClient(self.host, self.user, self.password, None, self.database, ENGINE_SQLITE, self.charset)
         my_pool = self.get_cur_client_pool_by_thread_id()
         sid = id(db_client)
         my_pool[sid] = db_client
-        dbg('无可用空闲链接，创建链接...', get_db_index(self.t_data))
         return db_client
 
     def get_free_client(self):
@@ -26,7 +26,7 @@ class SQLiteManager(ManagerBase):
         cur_time = int(time.time())
         my_pool = self.get_cur_client_pool_by_thread_id()
         for sid, client in my_pool.items():
-            if cur_time - client.last_connect_time < 30:
+            if cur_time - client.last_connect_time < TIMEOUT:
                 if client.is_lock is False:
                     my_client = client
                     break
